@@ -6,7 +6,7 @@ use File::Spec;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new{
 	my ($class,%opts) = @_;
@@ -377,7 +377,7 @@ sub _fill_in{
                 my @parts = ( $name );
                 @parts = split( /\Q$char\E/, $name ) if $char;
                 my $val = $self->_get_default_val($self->{defaults},@parts);
-                $frags[$i] =~ s/(?<!\Q$esc\E)$tda\s+$name\s+$tdb/$val/;
+                $frags[$i] =~ s/(?<!\Q$esc\E)$tda\s+$name\s+$tdb/$val/g;
             }
             
             if ( $esc ){
